@@ -2,7 +2,8 @@
  * AT-SPI - Assistive Technology Service Provider Interface
  * (Gnome Accessibility Project; http://developer.gnome.org/projects/gap)
  *
- * Copyright 2001 Sun Microsystems Inc.
+ * Copyright 2001, 2002 Sun Microsystems Inc.,
+ * Copyright 2001, 2002 Ximian, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -508,7 +509,7 @@ AccessibleTable_getSelectedRows (AccessibleTable *obj,
  * AccessibleTable_getNSelectedColumns:
  * @obj: a pointer to the #AccessibleTable implementor on which to operate.
  *
- * Query a table to find out how many columnss are currently selected.  Not all tables
+ * Query a table to find out how many columns are currently selected.  Not all tables
  *  support column selection.
  *
  * Returns: a long integer indicating the number of columns currently selected.
@@ -558,7 +559,7 @@ AccessibleTable_getSelectedColumns (AccessibleTable *obj,
 /**
  * AccessibleTable_isRowSelected:
  * @obj: a pointer to the #AccessibleTable implementor on which to operate.
- * @row:
+ * @row: the zero-indexed row number of the row being queried.
  *
  * Determine whether a table row is selected.  Not all tables support row selection.
  *
@@ -584,7 +585,7 @@ AccessibleTable_isRowSelected (AccessibleTable *obj,
 /**
  * AccessibleTable_isColumnSelected:
  * @obj: a pointer to the #AccessibleTable implementor on which to operate.
- * @column:
+ * @column: the zero-indexed column number of the column being queried.
  *
  * Determine whether specified table column is selected.
  * Not all tables support column selection.
@@ -611,7 +612,7 @@ AccessibleTable_isColumnSelected (AccessibleTable *obj,
 /**
  * AccessibleTable_addRowSelection:
  * @obj: a pointer to the #AccessibleTable implementor on which to operate.
- * @row:
+ * @row: the zero-indexed row number of the row being selected.
  *
  * Select the specified row, adding it to the current row selection.
  * Not all tables support row selection.
@@ -638,7 +639,7 @@ AccessibleTable_addRowSelection (AccessibleTable *obj,
 /**
  * AccessibleTable_addColumnSelection:
  * @obj: a pointer to the #AccessibleTable implementor on which to operate.
- * @column:
+ * @column: the zero-indexed column number of the column being selected.
  *
  * Select the specified column, adding it to the current column selection.
  * Not all tables support column selection.
@@ -665,7 +666,7 @@ AccessibleTable_addColumnSelection (AccessibleTable *obj,
 /**
  * AccessibleTable_removeRowSelection:
  * @obj: a pointer to the #AccessibleTable implementor on which to operate.
- * @row:
+ * @row: the zero-indexed number of the row being deselected.
  *
  * De-select the specified row, removing it to the current row selection.
  * Not all tables support row selection.
@@ -692,7 +693,7 @@ AccessibleTable_removeRowSelection (AccessibleTable *obj,
 /**
  * AccessibleTable_removeColumnSelection:
  * @obj: a pointer to the #AccessibleTable implementor on which to operate.
- * @column:
+ * @column: the zero-indexed column number of the column being de-selected.
  *
  * De-select the specified column, removing it to the current column selection.
  * Not all tables support column selection.
@@ -716,11 +717,52 @@ AccessibleTable_removeColumnSelection (AccessibleTable *obj,
   return retval;
 }
 
+
+SPIBoolean
+AccessibleTable_getRowColumnExtentsAtIndex (AccessibleTable *obj,
+					    long int index, long int *row, long int *col, 
+					    long int *row_extents, long int *col_extents, 
+					    long int *is_selected){
+  SPIBoolean retval;
+  CORBA_long cRow,  cCol, cRow_extents, cCol_extents; 
+  CORBA_boolean cIs_selected;
+
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval = Accessibility_Table_getRowColumnExtentsAtIndex (CSPI_OBJREF (obj),
+							   index, &cRow, &cCol,
+							   &cRow_extents, &cCol_extents,
+							   &cIs_selected,
+							   cspi_ev ());
+
+  if (!cspi_check_ev ("getRowColumnExtentsAtIndex")){
+    
+    *row = 0;
+    *col = 0;
+    *row_extents = 0;
+    *col_extents = 0;
+    *is_selected = FALSE;
+    retval = FALSE;
+  }
+
+  else {
+    *row = cRow;
+    *col = cCol;
+    *row_extents = cRow_extents;;
+    *col_extents = cCol_extents;
+    *is_selected = cIs_selected;;
+  }
+  
+  return retval;
+
+}
+
+
 /**
  * AccessibleTable_isSelected:
  * @obj: a pointer to the #AccessibleTable implementor on which to operate.
- * @row:
- * @column:
+ * @row: the zero-indexed row of the cell being queried.
+ * @column: the zero-indexed column of the cell being queried.
  *
  * Determine whether the cell at a specific row and column is selected.
  *
