@@ -221,7 +221,6 @@ spi_dec_replace_map_keysym (DEControllerPrivateData *priv, KeyCode keycode, KeyS
   if (desc && desc->map)
     {
       gint offset = desc->map->key_sym_map[keycode].offset;
-      long old_sym = desc->map->syms[offset]; 
       desc->map->syms[offset] = keysym; 
     }
   else
@@ -446,7 +445,10 @@ spi_dec_button_update_and_emit (SpiDEController *controller,
 	e.source = BONOBO_OBJREF (controller->registry->desktop);
 	e.detail1 = last_mouse_pos->x;
 	e.detail2 = last_mouse_pos->y;
-	spi_init_any_nil (&e.any_data);
+	spi_init_any_nil (&e.any_data, 
+		    spi_accessible_new_return (atk_get_root (), FALSE, NULL),
+		    Accessibility_ROLE_UNKNOWN,
+		    "");
 	CORBA_exception_init (&ev);
 	if (!is_consumed)
 	  {
@@ -500,7 +502,10 @@ spi_dec_mouse_check (SpiDEController *controller,
       e.source = BONOBO_OBJREF (controller->registry->desktop);
       e.detail1 = *x;
       e.detail2 = *y;
-      spi_init_any_nil (&e.any_data);
+      spi_init_any_nil (&e.any_data,
+		    spi_accessible_new_return (atk_get_root (), FALSE, NULL),
+		    Accessibility_ROLE_UNKNOWN,
+		    "");
       CORBA_exception_init (&ev);
       Accessibility_Registry_notifyEvent (BONOBO_OBJREF (controller->registry),
 					  &e,
@@ -509,7 +514,10 @@ spi_dec_mouse_check (SpiDEController *controller,
       e.source = BONOBO_OBJREF (controller->registry->desktop);
       e.detail1 = *x - last_mouse_pos->x;
       e.detail2 = *y - last_mouse_pos->y;
-      spi_init_any_nil (&e.any_data);
+      spi_init_any_nil (&e.any_data,
+		    spi_accessible_new_return (atk_get_root (), FALSE, NULL),
+		    Accessibility_ROLE_UNKNOWN,
+		    "");
       CORBA_exception_init (&ev);
       last_mouse_pos->x = *x;
       last_mouse_pos->y = *y;
@@ -548,7 +556,10 @@ spi_dec_emit_modifier_event (SpiDEController *controller, guint prev_mask,
   e.source = BONOBO_OBJREF (controller->registry->desktop);
   e.detail1 = prev_mask & key_modifier_mask;
   e.detail2 = current_mask & key_modifier_mask;
-  spi_init_any_nil (&e.any_data);
+  spi_init_any_nil (&e.any_data,
+		    spi_accessible_new_return (atk_get_root (), FALSE, NULL),
+		    Accessibility_ROLE_UNKNOWN,
+		    "");
   CORBA_exception_init (&ev);
   Accessibility_Registry_notifyEvent (BONOBO_OBJREF (controller->registry),
 				      &e,
@@ -617,7 +628,9 @@ spi_dec_ungrab_mouse (gpointer data)
 static void
 spi_dec_init_mouse_listener (SpiRegistry *registry)
 {
+#ifdef GRAB_BUTTON
   Display *display = spi_get_display ();
+#endif
   g_timeout_add (100, spi_dec_poll_mouse_idle, registry);
 
 #ifdef GRAB_BUTTON
@@ -920,8 +933,9 @@ spi_controller_notify_mouselisteners (SpiDEController                 *controlle
   GSList  *notify = NULL, *l2;
   GList  **listeners = &controller->mouse_listeners;
   gboolean is_consumed;
+#ifdef SPI_KEYEVENT_DEBUG
   gboolean found = FALSE;
-
+#endif
   if (!listeners)
     {
       return FALSE;
@@ -940,7 +954,9 @@ spi_controller_notify_mouselisteners (SpiDEController                 *controlle
 	       /* we clone (don't dup) the listener, to avoid refcount inc. */
 	       notify = g_slist_prepend (notify,
 					 spi_listener_clone (listener, ev));
+#ifdef SPI_KEYEVENT_DEBUG
                found = TRUE;
+#endif
 	     }
          }
     }
@@ -1058,7 +1074,10 @@ spi_device_event_controller_forward_mouse_event (SpiDEController *controller,
       e.source = BONOBO_OBJREF (controller->registry->desktop);
       e.detail1 = last_mouse_pos->x;
       e.detail2 = last_mouse_pos->y;
-      spi_init_any_nil (&e.any_data);
+      spi_init_any_nil (&e.any_data,
+		    spi_accessible_new_return (atk_get_root (), FALSE, NULL),
+		    Accessibility_ROLE_UNKNOWN,
+		    "");
       CORBA_exception_init (&ev);
       
       Accessibility_Registry_notifyEvent (BONOBO_OBJREF (controller->registry),
@@ -1451,7 +1470,8 @@ spi_controller_notify_keylisteners (SpiDEController                 *controller,
       DEControllerKeyListener *key_listener = l2->data;	    
       Accessibility_DeviceEventListener ls = key_listener->listener.object;
 
-      is_consumed = Accessibility_DeviceEventListener_notifyEvent (ls, key_event, ev);
+      is_consumed = Accessibility_DeviceEventListener_notifyEvent (ls, key_event, ev) &&
+	            key_listener->mode->preemptive;
 
       if (BONOBO_EX (ev))
         {
@@ -1480,7 +1500,7 @@ spi_controller_notify_keylisteners (SpiDEController                 *controller,
 }
 
 static gboolean
-spi_clear_error_state ()
+spi_clear_error_state (void)
 {
 	gboolean retval = spi_error_code != 0;
 	spi_error_code = 0;
@@ -2219,7 +2239,6 @@ impl_generate_keyboard_event (PortableServer_Servant           servant,
 {
   SpiDEController *controller =
 	SPI_DEVICE_EVENT_CONTROLLER (bonobo_object (servant));
-  long key_synth_code;
   gint err;
   KeySym keysym;
 
@@ -2235,7 +2254,6 @@ impl_generate_keyboard_event (PortableServer_Servant           servant,
    */
   
   gdk_error_trap_push ();
-  key_synth_code = keycode;
 
   switch (synth_type)
     {
@@ -2264,7 +2282,7 @@ impl_generate_keyboard_event (PortableServer_Servant           servant,
 			       keystring);
 	      break;
     }
-  if (err = gdk_error_trap_pop ())
+  if ((err = gdk_error_trap_pop ()))
     {
       DBG (-1, g_warning ("Error [%d] emitting keystroke", err));
     }
@@ -2517,7 +2535,6 @@ is_key_released (KeyCode code)
 {
   char keys[32];
   int down;
-  int i;
 
   XQueryKeymap (spi_get_display (), keys);
   down = BIT (keys, code);
